darkhistory.electrons.ics.ics_spectrum.thomson_spec — DarkHistory documentation

# darkhistory.electrons.ics.ics_spectrum.thomson_spec

`darkhistory.electrons.ics.ics_spectrum.` `thomson_spec`(eleckineng, photeng, T, as_pairs=False)

  Thomson ICS spectrum of secondary photons.

  Switches between thomson_spec_diff and thomson_spec_series.

  Parameters: | eleckineng : ndarray Incoming electron kinetic energy. photeng : ndarray Outgoing photon energy. T : float CMB temperature. as_pairs : bool If true, treats eleckineng and photeng as a paired list: produces eleckineng.size == photeng.size values. Otherwise, gets the spectrum at each photeng for each eleckineng, returning an array of length eleckineng.size*photeng.size.
  Returns: | TransFuncAtRedshift or ndarray dN/(dt dE) of the outgoing photons (dt = 1 s). If as_pairs == False, returns a TransFuncAtRedshift, with abscissa given by (eleckineng, photeng). Otherwise, returns an ndarray, with abscissa given by each pair of (eleckineng, photeng).

  Notes

  Insert note on the suitability of the method.

#### Previous topic

darkhistory.electrons.ics.ics_spectrum.thomson_spec_diff

#### Next topic

darkhistory.electrons.ics.ics_spectrum.thomson_spec_quad

### This Page

Show Source